@@ -59,6 +59,7 @@ from starlite.handlers import (
     asgi,
     delete,
     get,
+    head,
     patch,
     post,
     put,
@@ -158,6 +159,7 @@ __all__ = (
     "create_test_client",
     "delete",
     "get",
+    "head",
     "patch",
     "post",
     "put",
