@@ -4,7 +4,6 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union, cast
 
 from starlette.middleware.cors import CORSMiddleware
 from starlette.middleware.trustedhost import TrustedHostMiddleware
-from starlette.staticfiles import StaticFiles
 from typing_extensions import TypedDict
 
 from starlite.asgi import ASGIRouter
@@ -15,7 +14,7 @@ from starlite.connection import Request, WebSocket
 from starlite.datastructures.state import State
 from starlite.exceptions import NoRouteMatchFoundException
 from starlite.handlers.http import HTTPRouteHandler
-from starlite.middleware.compression.base import CompressionMiddleware
+from starlite.middleware.compression import CompressionMiddleware
 from starlite.router import Router
 from starlite.routes import ASGIRoute, HTTPRoute, WebSocketRoute
 from starlite.signature import SignatureModelFactory
@@ -41,7 +40,6 @@ if TYPE_CHECKING:
         AfterExceptionHookHandler,
         AfterRequestHookHandler,
         AfterResponseHookHandler,
-        AnyCallable,
         ASGIApp,
         BeforeMessageSendHookHandler,
         BeforeRequestHookHandler,
@@ -67,7 +65,7 @@ if TYPE_CHECKING:
         Send,
         SingleOrList,
     )
-    from starlite.types.callable_types import GetLogger
+    from starlite.types.callable_types import AnyCallable, GetLogger
 
 DEFAULT_OPENAPI_CONFIG = OpenAPIConfig(title="Starlite API", version="1.0.0")
 """
@@ -183,8 +181,7 @@ class Starlite(Router):
                 or list thereof.This hook is called after an exception occurs. In difference to exception handlers,
                 it is not meant to return a response - only to process the exception (e.g. log it, send it to Sentry etc.).
             after_request: A sync or async function executed after the route handler function returned and the response
-                object has been resolved. Receives the response object which may be either an instance of
-                [Response][starlite.response.Response] or `starlette.Response`.
+                object has been resolved. Receives the response object.
             after_response: A sync or async function called after the response has been awaited. It receives the
                 [Request][starlite.connection.Request] object and should not return any values.
             after_shutdown: An application level [life-span hook handler][starlite.types.LifeSpanHookHandler] or
@@ -554,6 +551,8 @@ class Starlite(Router):
         Returns:
             A url path to the asset.
         """
+        from starlite.static_files.base import StaticFiles
+
         handler_index = self.get_handler_index_by_name(name)
         if handler_index is None:
             raise NoRouteMatchFoundException(f"Static handler {name} can not be found")
