@@ -4,11 +4,13 @@ from enum import Enum
 class HttpMethod(str, Enum):
     """An Enum for HTTP methods."""
 
+    DELETE = "DELETE"
     GET = "GET"
+    HEAD = "HEAD"
+    OPTIONS = "OPTIONS"
+    PATCH = "PATCH"
     POST = "POST"
     PUT = "PUT"
-    PATCH = "PATCH"
-    DELETE = "DELETE"
 
 
 class MediaType(str, Enum):
@@ -54,3 +56,10 @@ class ParamType(str, Enum):
     QUERY = "query"
     COOKIE = "cookie"
     HEADER = "header"
+
+
+class CompressionEncoding(str, Enum):
+    """An Enum for supported compression encodings."""
+
+    GZIP = "gzip"
+    BROTLI = "br"
