@@ -35,7 +35,7 @@ class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             name: A string identifying the route handler.
-            opt: A string key dictionary of arbitrary values that can be accessed [Guards][starlite.types.Guard].
+            opt: A string key dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
             path: A path fragment for the route handler function or a list of path fragments. If not given defaults to '/'
             is_mount: A boolean dictating whether the handler's paths should be regarded as mount paths. Mount path accept
                 any arbitrary paths that begin with the defined prefixed path. For example, a mount with the path `/some-path/`
@@ -62,7 +62,7 @@ class ASGIRouteHandler(BaseRouteHandler["ASGIRouteHandler"]):
         fn = cast("AnyCallable", self.fn)
         signature = Signature.from_callable(fn)
 
-        if signature.return_annotation is not None:
+        if signature.return_annotation not in {None, "None"}:
             raise ImproperlyConfiguredException("ASGI handler functions should return 'None'")
 
         if any(key not in signature.parameters for key in ("scope", "send", "receive")):
