@@ -8,6 +8,7 @@ from typing import (
     Dict,
     List,
     Optional,
+    Set,
     Type,
     Union,
     cast,
@@ -33,7 +34,7 @@ from starlite.exceptions import (
 from starlite.handlers.base import BaseRouteHandler
 from starlite.openapi.datastructures import ResponseSpec
 from starlite.plugins import get_plugin_for_value
-from starlite.response import Response
+from starlite.response import FileResponse, Response
 from starlite.status_codes import (
     HTTP_200_OK,
     HTTP_201_CREATED,
@@ -168,7 +169,7 @@ def _create_response_handler(
 def _create_generic_asgi_response_handler(
     after_request: Optional["AfterRequestHookHandler"], cookies: "ResponseCookies"
 ) -> "AsyncAnyCallable":
-    """Creates a handler function for Starlette Responses."""
+    """Creates a handler function for Responses."""
 
     async def handler(data: "ASGIApp", **kwargs: Any) -> "ASGIApp":
         normalized_cookies = _normalize_cookies(cookies, [])
@@ -211,6 +212,42 @@ def _create_data_handler(
     return handler
 
 
+def _normalize_http_method(http_methods: Union[HttpMethod, Method, List[Union[HttpMethod, Method]]]) -> Set["Method"]:
+    """
+
+    Args:
+        http_methods: A value for http method.
+
+    Returns:
+        A normalized set of http methods.
+    """
+    output: Set[str] = set()
+
+    for method in http_methods if isinstance(http_methods, list) else [http_methods]:
+        if isinstance(method, HttpMethod):
+            output.add(method.value.upper())
+        else:
+            output.add(method.upper())
+
+    return cast("Set[Method]", output)
+
+
+def _get_default_status_code(http_methods: Set["Method"]) -> int:
+    """
+
+    Args:
+        http_methods: A set of Method strings.
+
+    Returns:
+        A status code integer.
+    """
+    if HttpMethod.POST in http_methods:
+        return HTTP_201_CREATED
+    if HttpMethod.DELETE in http_methods:
+        return HTTP_204_NO_CONTENT
+    return HTTP_200_OK
+
+
 class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
     __slots__ = (
         "_resolved_after_response",
@@ -228,7 +265,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         "deprecated",
         "description",
         "etag",
-        "http_method",
+        "http_methods",
         "include_in_schema",
         "media_type",
         "operation_id",
@@ -348,20 +385,10 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         """
         if not http_method:
             raise ImproperlyConfiguredException("An http_method kwarg is required")
-        if isinstance(http_method, list):
-            self.http_method: Union[List[str], str] = [v.upper() for v in http_method]
-            if len(http_method) == 1:
-                self.http_method = http_method[0]
-        else:
-            self.http_method = http_method.value if isinstance(http_method, HttpMethod) else http_method
-        if status_code:
-            self.status_code = status_code
-        elif self.http_method == HttpMethod.POST:
-            self.status_code = HTTP_201_CREATED
-        elif self.http_method == HttpMethod.DELETE:
-            self.status_code = HTTP_204_NO_CONTENT
-        else:
-            self.status_code = HTTP_200_OK
+
+        self.http_methods = _normalize_http_method(http_methods=http_method)
+        self.status_code = status_code or _get_default_status_code(http_methods=self.http_methods)
+
         super().__init__(
             path,
             dependencies=dependencies,
@@ -372,6 +399,7 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
             opt=opt,
             **kwargs,
         )
+
         self.after_request = AsyncCallable(after_request) if after_request else None  # type: ignore[arg-type]
         self.after_response = AsyncCallable(after_response) if after_response else None
         self.background = background
@@ -571,14 +599,6 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         response_handler = self.resolve_response_handler()
         return await response_handler(app=app, data=data, plugins=plugins, request=request)  # type: ignore
 
-    @property
-    def http_methods(self) -> List["Method"]:
-        """
-        Returns:
-            A list of the RouteHandler's [HttpMethod][starlite.types.Method] strings
-        """
-        return cast("List[Method]", self.http_method if isinstance(self.http_method, list) else [self.http_method])
-
     @property
     def signature(self) -> Signature:
         """
@@ -591,28 +611,42 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         """Validates the route handler function once it is set by inspecting
         its return annotations."""
         super()._validate_handler_function()
-        return_annotation = self.signature.return_annotation
-        if return_annotation is Signature.empty:
+
+        if self.signature.return_annotation is Signature.empty:
             raise ImproperlyConfiguredException(
                 "A return value of a route handler function should be type annotated."
                 "If your function doesn't return a value, annotate it as returning 'None'."
             )
+
         if (
             self.status_code < 200 or self.status_code in {HTTP_204_NO_CONTENT, HTTP_304_NOT_MODIFIED}
-        ) and return_annotation is not None:
+        ) and self.signature.return_annotation not in {None, "None"}:
             raise ImproperlyConfiguredException(
                 "A status code 204, 304 or in the range below 200 does not support a response body."
                 "If the function should return a value, change the route handler status code to an appropriate value.",
             )
-        if is_class_and_subclass(return_annotation, Redirect) and self.status_code not in REDIRECT_STATUS_CODES:
+
+        if (
+            is_class_and_subclass(self.signature.return_annotation, Redirect)
+            and self.status_code not in REDIRECT_STATUS_CODES
+        ):
             raise ValidationException(
                 f"Redirect responses should have one of "
                 f"the following status codes: {', '.join([str(s) for s in REDIRECT_STATUS_CODES])}"
             )
-        if is_class_and_subclass(return_annotation, File) and self.media_type in (MediaType.JSON, MediaType.HTML):
+
+        if (
+            is_class_and_subclass(self.signature.return_annotation, File)
+            or is_class_and_subclass(self.signature.return_annotation, FileResponse)
+        ) and self.media_type in (
+            MediaType.JSON,
+            MediaType.HTML,
+        ):
             self.media_type = MediaType.TEXT
+
         if "socket" in self.signature.parameters:
             raise ImproperlyConfiguredException("The 'socket' kwarg is not supported with http handlers")
+
         if "data" in self.signature.parameters and "GET" in self.http_methods:
             raise ImproperlyConfiguredException("'data' kwarg is unsupported for 'GET' request handlers")
 
@@ -757,6 +791,162 @@ class get(HTTPRouteHandler):
         )
 
 
+class head(HTTPRouteHandler):
+    @validate_arguments(config={"arbitrary_types_allowed": True})
+    def __init__(
+        self,
+        path: Union[Optional[str], Optional[List[str]]] = None,
+        *,
+        after_request: Optional[AfterRequestHookHandler] = None,
+        after_response: Optional[AfterResponseHookHandler] = None,
+        background: Optional[Union[BackgroundTask, BackgroundTasks]] = None,
+        before_request: Optional[BeforeRequestHookHandler] = None,
+        cache: Union[bool, int] = False,
+        cache_control: Optional[CacheControlHeader] = None,
+        cache_key_builder: Optional[CacheKeyBuilder] = None,
+        dependencies: Optional[Dict[str, Provide]] = None,
+        etag: Optional[ETag] = None,
+        exception_handlers: Optional[ExceptionHandlersMap] = None,
+        guards: Optional[List[Guard]] = None,
+        media_type: Union[MediaType, str] = MediaType.JSON,
+        middleware: Optional[List[Middleware]] = None,
+        name: Optional[str] = None,
+        opt: Optional[Dict[str, Any]] = None,
+        response_class: Optional[ResponseType] = None,
+        response_cookies: Optional[ResponseCookies] = None,
+        response_headers: Optional[ResponseHeadersMap] = None,
+        status_code: Optional[int] = None,
+        sync_to_thread: bool = False,
+        # OpenAPI related attributes
+        content_encoding: Optional[str] = None,
+        content_media_type: Optional[str] = None,
+        deprecated: bool = False,
+        description: Optional[str] = None,
+        include_in_schema: bool = True,
+        operation_id: Optional[str] = None,
+        raises: Optional[List[Type[HTTPException]]] = None,
+        response_description: Optional[str] = None,
+        responses: Optional[Dict[int, ResponseSpec]] = None,
+        security: Optional[List[SecurityRequirement]] = None,
+        summary: Optional[str] = None,
+        tags: Optional[List[str]] = None,
+        **kwargs: Any,
+    ) -> None:
+        """HEAD Route Decorator. Use this decorator to decorate an HTTP handler
+        for HEAD requests.
+
+        Notes:
+            - A response to a head request cannot include a body.
+                See: [MDN](https://developer.mozilla.org/en-US/docs/Web/HTTP/Methods/HEAD).
+
+        Args:
+            path: A path fragment for the route handler function or a list of path fragments.
+                If not given defaults to '/'
+            after_request: A sync or async function executed before a [Request][starlite.connection.Request] is passed
+                to any route handler. If this function returns a value, the request will not reach the route handler,
+                and instead this value will be used.
+            after_response: A sync or async function called after the response has been awaited. It receives the
+                [Request][starlite.connection.Request] object and should not return any values.
+            background: A [BackgroundTask][starlite.datastructures.BackgroundTask] instance or
+                [BackgroundTasks][starlite.datastructures.BackgroundTasks] to execute after the response is finished.
+                Defaults to None.
+            before_request: A sync or async function called immediately before calling the route handler. Receives
+                the `starlite.connection.Request` instance and any non-`None` return value is used for the response,
+                bypassing the route handler.
+            cache: Enables response caching if configured on the application level. Valid values are 'true' or a number
+                of seconds (e.g. '120') to cache the response.
+            cache_control: A `cache-control` header of type
+                [CacheControlHeader][starlite.datastructures.CacheControlHeader] that will be added to the response.
+            cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
+                of the cache key if caching is configured on the application level.
+            dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
+            exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
+            guards: A list of [Guard][starlite.types.Guard] callables.
+            media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
+                valid IANA Media-Type.
+            middleware: A list of [Middleware][starlite.types.Middleware].
+            name: A string identifying the route handler.
+            opt: A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+            response_class: A custom subclass of [starlite.response.Response] to be used as route handler's
+                default response.
+            response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
+            response_headers: A string keyed dictionary mapping [ResponseHeader][starlite.datastructures.ResponseHeader]
+                instances.
+            responses: A dictionary of additional status codes and a description of their expected content.
+                This information will be included in the OpenAPI schema
+            status_code: An http status code for the response. Defaults to '200'.
+            sync_to_thread: A boolean dictating whether the handler function will be executed in a worker thread or the
+                main event loop. This has an effect only for sync handler functions. See using sync handler functions.
+            content_encoding: A string describing the encoding of the content, e.g. "base64".
+            content_media_type: A string designating the media-type of the content, e.g. "image/png".
+            deprecated:  A boolean dictating whether this route should be marked as deprecated in the OpenAPI schema.
+            description: Text used for the route's schema description section.
+            include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
+            operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
+            response_description: Text used for the route's response schema description section.
+            security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
+            summary: Text used for the route's schema summary section.
+            tags: A list of string tags that will be appended to the OpenAPI schema.
+            **kwargs: Any additional kwarg - will be set in the opt dictionary.
+        """
+        if "http_method" in kwargs:
+            raise ImproperlyConfiguredException(MSG_SEMANTIC_ROUTE_HANDLER_WITH_HTTP)
+
+        super().__init__(
+            after_request=after_request,
+            after_response=after_response,
+            background=background,
+            before_request=before_request,
+            cache=cache,
+            cache_control=cache_control,
+            cache_key_builder=cache_key_builder,
+            content_encoding=content_encoding,
+            content_media_type=content_media_type,
+            dependencies=dependencies,
+            deprecated=deprecated,
+            description=description,
+            etag=etag,
+            exception_handlers=exception_handlers,
+            guards=guards,
+            http_method=HttpMethod.HEAD,
+            include_in_schema=include_in_schema,
+            media_type=media_type,
+            middleware=middleware,
+            name=name,
+            operation_id=operation_id,
+            opt=opt,
+            path=path,
+            raises=raises,
+            response_class=response_class,
+            response_cookies=response_cookies,
+            response_description=response_description,
+            response_headers=response_headers,
+            responses=responses,
+            security=security,
+            status_code=status_code,
+            summary=summary,
+            sync_to_thread=sync_to_thread,
+            tags=tags,
+            **kwargs,
+        )
+
+    def _validate_handler_function(self) -> None:
+        """Validates the route handler function once it is set by inspecting
+        its return annotations."""
+        super()._validate_handler_function()
+
+        # we allow here File and FileResponse because these have special setting for head responses
+        if not (
+            self.signature.return_annotation in {None, "None", "FileResponse", "File"}
+            or is_class_and_subclass(self.signature.return_annotation, File)
+            or is_class_and_subclass(self.signature.return_annotation, FileResponse)
+        ):
+            raise ImproperlyConfiguredException(
+                "A response to a head request should not have a body",
+            )
+
+
 class post(HTTPRouteHandler):
     @validate_arguments(config={"arbitrary_types_allowed": True})
     def __init__(
@@ -984,8 +1174,8 @@ class put(HTTPRouteHandler):
             include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
             operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
             raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation.
-                This list should describe all exceptions raised within the route handler's function/method. T
-                he Starlite ValidationException will be added automatically for the schema if any validation is involved.
+                This list should describe all exceptions raised within the route handler's function/method. The Starlite
+                ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
