@@ -2,7 +2,11 @@ from starlite.middleware.authentication import (
     AbstractAuthenticationMiddleware,
     AuthenticationResult,
 )
-from starlite.middleware.base import DefineMiddleware, MiddlewareProtocol
+from starlite.middleware.base import (
+    AbstractMiddleware,
+    DefineMiddleware,
+    MiddlewareProtocol,
+)
 from starlite.middleware.compression import CompressionMiddleware
 from starlite.middleware.csrf import CSRFMiddleware
 from starlite.middleware.exceptions import ExceptionHandlerMiddleware
@@ -11,6 +15,7 @@ from starlite.middleware.rate_limit import RateLimitConfig, RateLimitMiddleware
 
 __all__ = (
     "AbstractAuthenticationMiddleware",
+    "AbstractMiddleware",
     "AuthenticationResult",
     "CSRFMiddleware",
     "CompressionMiddleware",
