@@ -2,8 +2,7 @@ import re
 import secrets
 from typing import TYPE_CHECKING, Any, Optional, Pattern
 
-from starlette.datastructures import MutableHeaders
-
+from starlite.datastructures import MutableScopeHeaders
 from starlite.datastructures.cookie import Cookie
 from starlite.enums import RequestEncodingType, ScopeType
 from starlite.exceptions import PermissionDeniedException
@@ -112,7 +111,7 @@ class CSRFMiddleware(MiddlewareProtocol):
         return send_wrapper
 
     def _set_cookie_if_needed(self, message: "HTTPSendMessage", token: str) -> None:
-        headers = MutableHeaders(scope=message)
+        headers = MutableScopeHeaders.from_message(message)
         cookie = Cookie(
             key=self.config.cookie_name,
             value=token,
@@ -122,7 +121,7 @@ class CSRFMiddleware(MiddlewareProtocol):
             samesite=self.config.cookie_samesite,
             domain=self.config.cookie_domain,
         )
-        headers.append("set-cookie", cookie.to_header(header=""))
+        headers.add("set-cookie", cookie.to_header(header=""))
 
     def _decode_csrf_token(self, token: str) -> Optional[str]:
         """Decode a CSRF token and validate its HMAC."""
