@@ -16,10 +16,10 @@ from typing import (
 
 from orjson import dumps, loads
 from pydantic import BaseModel, validator
-from starlette.datastructures import MutableHeaders
 from typing_extensions import Literal
 
 from starlite.connection import Request
+from starlite.datastructures import MutableScopeHeaders
 from starlite.enums import ScopeType
 from starlite.exceptions import TooManyRequestsException
 from starlite.middleware.base import DefineMiddleware
@@ -128,9 +128,9 @@ class RateLimitMiddleware:
             """
             if message["type"] == "http.response.start":
                 message.setdefault("headers", [])
-                headers = MutableHeaders(scope=message)
+                headers = MutableScopeHeaders(message)
                 for key, value in self.create_response_headers(cache_object=cache_object).items():
-                    headers.append(key, value)
+                    headers.add(key, value)
             await send(message)
 
         return send_wrapper
