@@ -12,7 +12,7 @@ from typing import (
 )
 
 from orjson import OPT_SERIALIZE_NUMPY, dumps, loads
-from pydantic import BaseConfig, BaseModel, validator
+from pydantic import BaseConfig, BaseModel, root_validator, validator
 from typing_extensions import Literal
 
 from starlite.config.logging import BaseLoggingConfig, LoggingConfig
@@ -20,6 +20,8 @@ from starlite.exceptions import MissingDependencyException
 from starlite.types import BeforeMessageSendHookHandler
 from starlite.utils import AsyncCallable, default_serializer
 
+from .types import SessionMakerInstanceProtocol, SessionMakerTypeProtocol
+
 try:
     from sqlalchemy import create_engine
     from sqlalchemy.engine import Engine
@@ -147,7 +149,7 @@ class SQLAlchemyConfig(BaseModel):
     class Config(BaseConfig):
         arbitrary_types_allowed = True
 
-    connection_string: str
+    connection_string: Optional[str] = None
     """Database connection string in one of the formats supported by SQLAlchemy.
 
     Notes:
@@ -200,7 +202,7 @@ class SQLAlchemyConfig(BaseModel):
     Configuration options for the 'sessionmaker'. The configuration options are documented in the
         SQLAlchemy documentation.
     """
-    session_maker_class: Type[sessionmaker] = sessionmaker
+    session_maker_class: Type[SessionMakerTypeProtocol] = sessionmaker
     """
     Sessionmaker class to use.
     """
@@ -208,7 +210,7 @@ class SQLAlchemyConfig(BaseModel):
     """
     Key under which to store the SQLAlchemy 'sessionmaker' in the application [State][starlite.datastructures.State] instance.
     """
-    session_maker_instance: Optional[sessionmaker] = None
+    session_maker_instance: Optional[SessionMakerInstanceProtocol] = None
     """
     Optional sessionmaker to use. If set, the plugin will use the provided instance rather than instantiate a sessionmaker.
     """
@@ -236,6 +238,30 @@ class SQLAlchemyConfig(BaseModel):
         """
         return AsyncCallable(value)  # type: ignore[arg-type]
 
+    @root_validator
+    def check_connection_string_or_engine_instance(  # pylint: disable=no-self-argument
+        cls, values: Dict[str, Any]
+    ) -> Dict[str, Any]:
+        """Either `connection_string` or `engine_instance` must be specified,
+        and not both.
+
+        Args:
+            values: Field values, after validation.
+
+        Returns:
+            Field values.
+        """
+        connection_string = values.get("connection_string")
+        engine_instance = values.get("engine_instance")
+
+        if connection_string is None and engine_instance is None:
+            raise ValueError("One of 'connection_string' or 'engine_instance' must be provided.")
+
+        if connection_string is not None and engine_instance is not None:
+            raise ValueError("Only one of 'connection_string' or 'engine_instance' can be provided.")
+
+        return values
+
     @property
     def engine_config_dict(self) -> Dict[str, Any]:
         """
@@ -261,7 +287,9 @@ class SQLAlchemyConfig(BaseModel):
             create_engine_callable = (
                 self.create_async_engine_callable if self.use_async_engine else self.create_engine_callable
             )
-            self.engine_instance = create_engine_callable(self.connection_string, **self.engine_config_dict)
+            self.engine_instance = create_engine_callable(
+                self.connection_string, **self.engine_config_dict  # type:ignore[arg-type]
+            )
         return cast("Union[Engine, FutureEngine, AsyncEngine]", self.engine_instance)
 
     @property
