@@ -3,7 +3,6 @@ from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union, cast
 
 from pydantic import BaseModel
 
-from starlite.enums import MediaType
 from starlite.status_codes import HTTP_500_INTERNAL_SERVER_ERROR
 
 if TYPE_CHECKING:
@@ -66,7 +65,6 @@ class ExceptionResponseContent(BaseModel):
         return Response(
             content=self.dict(exclude_none=True, exclude={"headers"}),
             headers=self.headers,
-            media_type=MediaType.JSON,
             status_code=self.status_code,
         )
 
@@ -74,8 +72,10 @@ class ExceptionResponseContent(BaseModel):
 def create_exception_response(exc: Exception) -> "Response":
     """Constructs a response from an exception.
 
-    For instances of either `starlite.exceptions.HTTPException` or `starlette.exceptions.HTTPException` the response
-    status code is drawn from the exception, otherwise response status is `HTTP_500_INTERNAL_SERVER_ERROR`.
+    Notes:
+    - For instances of [HTTPException][starlite.exceptions.HTTPException] or other exception classes that have a
+        `status_code` attribute (e.g. Starlette exceptions), the status code is drawn from the exception, otherwise
+        response status is `HTTP_500_INTERNAL_SERVER_ERROR`.
 
     Args:
         exc: An exception.
